# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..types import access_ip_address_list_params, access_ip_address_create_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..pagination import SyncDefaultFlatPagination, AsyncDefaultFlatPagination
from .._base_client import AsyncPaginator, make_request_options
from ..types.access_ip_address_response import AccessIPAddressResponse

__all__ = ["AccessIPAddressResource", "AsyncAccessIPAddressResource"]


class AccessIPAddressResource(SyncAPIResource):
    """IP Address Operations"""

    @cached_property
    def with_raw_response(self) -> AccessIPAddressResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AccessIPAddressResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AccessIPAddressResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AccessIPAddressResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        ip_address: str,
        description: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AccessIPAddressResponse:
        """
        Create new Access IP Address

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/access_ip_address",
            body=maybe_transform(
                {
                    "ip_address": ip_address,
                    "description": description,
                },
                access_ip_address_create_params.AccessIPAddressCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AccessIPAddressResponse,
        )

    def retrieve(
        self,
        access_ip_address_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AccessIPAddressResponse:
        """
        Retrieve an access IP address

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not access_ip_address_id:
            raise ValueError(
                f"Expected a non-empty value for `access_ip_address_id` but received {access_ip_address_id!r}"
            )
        return self._get(
            f"/access_ip_address/{access_ip_address_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AccessIPAddressResponse,
        )

    def list(
        self,
        *,
        filter: access_ip_address_list_params.Filter | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SyncDefaultFlatPagination[AccessIPAddressResponse]:
        """
        List all Access IP Addresses

        Args:
          filter: Consolidated filter parameter (deepObject style). Originally: filter[ip_source],
              filter[ip_address], filter[created_at]. Supports complex bracket operations for
              dynamic filtering.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/access_ip_address",
            page=SyncDefaultFlatPagination[AccessIPAddressResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    access_ip_address_list_params.AccessIPAddressListParams,
                ),
            ),
            model=AccessIPAddressResponse,
        )

    def delete(
        self,
        access_ip_address_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AccessIPAddressResponse:
        """
        Delete access IP address

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not access_ip_address_id:
            raise ValueError(
                f"Expected a non-empty value for `access_ip_address_id` but received {access_ip_address_id!r}"
            )
        return self._delete(
            f"/access_ip_address/{access_ip_address_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AccessIPAddressResponse,
        )


class AsyncAccessIPAddressResource(AsyncAPIResource):
    """IP Address Operations"""

    @cached_property
    def with_raw_response(self) -> AsyncAccessIPAddressResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncAccessIPAddressResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncAccessIPAddressResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncAccessIPAddressResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        ip_address: str,
        description: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AccessIPAddressResponse:
        """
        Create new Access IP Address

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/access_ip_address",
            body=await async_maybe_transform(
                {
                    "ip_address": ip_address,
                    "description": description,
                },
                access_ip_address_create_params.AccessIPAddressCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AccessIPAddressResponse,
        )

    async def retrieve(
        self,
        access_ip_address_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AccessIPAddressResponse:
        """
        Retrieve an access IP address

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not access_ip_address_id:
            raise ValueError(
                f"Expected a non-empty value for `access_ip_address_id` but received {access_ip_address_id!r}"
            )
        return await self._get(
            f"/access_ip_address/{access_ip_address_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AccessIPAddressResponse,
        )

    def list(
        self,
        *,
        filter: access_ip_address_list_params.Filter | Omit = omit,
        page_number: int | Omit = omit,
        page_size: int | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AsyncPaginator[AccessIPAddressResponse, AsyncDefaultFlatPagination[AccessIPAddressResponse]]:
        """
        List all Access IP Addresses

        Args:
          filter: Consolidated filter parameter (deepObject style). Originally: filter[ip_source],
              filter[ip_address], filter[created_at]. Supports complex bracket operations for
              dynamic filtering.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get_api_list(
            "/access_ip_address",
            page=AsyncDefaultFlatPagination[AccessIPAddressResponse],
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "filter": filter,
                        "page_number": page_number,
                        "page_size": page_size,
                    },
                    access_ip_address_list_params.AccessIPAddressListParams,
                ),
            ),
            model=AccessIPAddressResponse,
        )

    async def delete(
        self,
        access_ip_address_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> AccessIPAddressResponse:
        """
        Delete access IP address

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not access_ip_address_id:
            raise ValueError(
                f"Expected a non-empty value for `access_ip_address_id` but received {access_ip_address_id!r}"
            )
        return await self._delete(
            f"/access_ip_address/{access_ip_address_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=AccessIPAddressResponse,
        )


class AccessIPAddressResourceWithRawResponse:
    def __init__(self, access_ip_address: AccessIPAddressResource) -> None:
        self._access_ip_address = access_ip_address

        self.create = to_raw_response_wrapper(
            access_ip_address.create,
        )
        self.retrieve = to_raw_response_wrapper(
            access_ip_address.retrieve,
        )
        self.list = to_raw_response_wrapper(
            access_ip_address.list,
        )
        self.delete = to_raw_response_wrapper(
            access_ip_address.delete,
        )


class AsyncAccessIPAddressResourceWithRawResponse:
    def __init__(self, access_ip_address: AsyncAccessIPAddressResource) -> None:
        self._access_ip_address = access_ip_address

        self.create = async_to_raw_response_wrapper(
            access_ip_address.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            access_ip_address.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            access_ip_address.list,
        )
        self.delete = async_to_raw_response_wrapper(
            access_ip_address.delete,
        )


class AccessIPAddressResourceWithStreamingResponse:
    def __init__(self, access_ip_address: AccessIPAddressResource) -> None:
        self._access_ip_address = access_ip_address

        self.create = to_streamed_response_wrapper(
            access_ip_address.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            access_ip_address.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            access_ip_address.list,
        )
        self.delete = to_streamed_response_wrapper(
            access_ip_address.delete,
        )


class AsyncAccessIPAddressResourceWithStreamingResponse:
    def __init__(self, access_ip_address: AsyncAccessIPAddressResource) -> None:
        self._access_ip_address = access_ip_address

        self.create = async_to_streamed_response_wrapper(
            access_ip_address.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            access_ip_address.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            access_ip_address.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            access_ip_address.delete,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.ai.conversations.message_list_response import MessageListResponse

__all__ = ["MessagesResource", "AsyncMessagesResource"]


class MessagesResource(SyncAPIResource):
    """Manage historical AI assistant conversations"""

    @cached_property
    def with_raw_response(self) -> MessagesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return MessagesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> MessagesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return MessagesResourceWithStreamingResponse(self)

    def list(
        self,
        conversation_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessageListResponse:
        """
        Retrieve messages for a specific conversation, including tool calls made by the
        assistant.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not conversation_id:
            raise ValueError(f"Expected a non-empty value for `conversation_id` but received {conversation_id!r}")
        return self._get(
            f"/ai/conversations/{conversation_id}/messages",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessageListResponse,
        )


class AsyncMessagesResource(AsyncAPIResource):
    """Manage historical AI assistant conversations"""

    @cached_property
    def with_raw_response(self) -> AsyncMessagesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncMessagesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncMessagesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncMessagesResourceWithStreamingResponse(self)

    async def list(
        self,
        conversation_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> MessageListResponse:
        """
        Retrieve messages for a specific conversation, including tool calls made by the
        assistant.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not conversation_id:
            raise ValueError(f"Expected a non-empty value for `conversation_id` but received {conversation_id!r}")
        return await self._get(
            f"/ai/conversations/{conversation_id}/messages",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=MessageListResponse,
        )


class MessagesResourceWithRawResponse:
    def __init__(self, messages: MessagesResource) -> None:
        self._messages = messages

        self.list = to_raw_response_wrapper(
            messages.list,
        )


class AsyncMessagesResourceWithRawResponse:
    def __init__(self, messages: AsyncMessagesResource) -> None:
        self._messages = messages

        self.list = async_to_raw_response_wrapper(
            messages.list,
        )


class MessagesResourceWithStreamingResponse:
    def __init__(self, messages: MessagesResource) -> None:
        self._messages = messages

        self.list = to_streamed_response_wrapper(
            messages.list,
        )


class AsyncMessagesResourceWithStreamingResponse:
    def __init__(self, messages: AsyncMessagesResource) -> None:
        self._messages = messages

        self.list = async_to_streamed_response_wrapper(
            messages.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .jobs import (
    JobsResource,
    AsyncJobsResource,
    JobsResourceWithRawResponse,
    AsyncJobsResourceWithRawResponse,
    JobsResourceWithStreamingResponse,
    AsyncJobsResourceWithStreamingResponse,
)
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource

__all__ = ["PhoneNumberBlocksResource", "AsyncPhoneNumberBlocksResource"]


class PhoneNumberBlocksResource(SyncAPIResource):
    @cached_property
    def jobs(self) -> JobsResource:
        """Background jobs performed over a phone-numbers block's phone numbers"""
        return JobsResource(self._client)

    @cached_property
    def with_raw_response(self) -> PhoneNumberBlocksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return PhoneNumberBlocksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PhoneNumberBlocksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return PhoneNumberBlocksResourceWithStreamingResponse(self)


class AsyncPhoneNumberBlocksResource(AsyncAPIResource):
    @cached_property
    def jobs(self) -> AsyncJobsResource:
        """Background jobs performed over a phone-numbers block's phone numbers"""
        return AsyncJobsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncPhoneNumberBlocksResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPhoneNumberBlocksResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPhoneNumberBlocksResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/team-telnyx/telnyx-python#with_streaming_response
        """
        return AsyncPhoneNumberBlocksResourceWithStreamingResponse(self)


class PhoneNumberBlocksResourceWithRawResponse:
    def __init__(self, phone_number_blocks: PhoneNumberBlocksResource) -> None:
        self._phone_number_blocks = phone_number_blocks

    @cached_property
    def jobs(self) -> JobsResourceWithRawResponse:
        """Background jobs performed over a phone-numbers block's phone numbers"""
        return JobsResourceWithRawResponse(self._phone_number_blocks.jobs)


class AsyncPhoneNumberBlocksResourceWithRawResponse:
    def __init__(self, phone_number_blocks: AsyncPhoneNumberBlocksResource) -> None:
        self._phone_number_blocks = phone_number_blocks

    @cached_property
    def jobs(self) -> AsyncJobsResourceWithRawResponse:
        """Background jobs performed over a phone-numbers block's phone numbers"""
        return AsyncJobsResourceWithRawResponse(self._phone_number_blocks.jobs)


class PhoneNumberBlocksResourceWithStreamingResponse:
    def __init__(self, phone_number_blocks: PhoneNumberBlocksResource) -> None:
        self._phone_number_blocks = phone_number_blocks

    @cached_property
    def jobs(self) -> JobsResourceWithStreamingResponse:
        """Background jobs performed over a phone-numbers block's phone numbers"""
        return JobsResourceWithStreamingResponse(self._phone_number_blocks.jobs)


class AsyncPhoneNumberBlocksResourceWithStreamingResponse:
    def __init__(self, phone_number_blocks: AsyncPhoneNumberBlocksResource) -> None:
        self._phone_number_blocks = phone_number_blocks

    @cached_property
    def jobs(self) -> AsyncJobsResourceWithStreamingResponse:
        """Background jobs performed over a phone-numbers block's phone numbers"""
        return AsyncJobsResourceWithStreamingResponse(self._phone_number_blocks.jobs)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from telnyx import Telnyx, AsyncTelnyx
from tests.utils import assert_matches_type

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestMcpServers:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_create_mcp_server(self, client: Telnyx) -> None:
        mcp_server = client.ai.missions.mcp_servers.create_mcp_server(
            "mission_id",
        )
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_create_mcp_server(self, client: Telnyx) -> None:
        response = client.ai.missions.mcp_servers.with_raw_response.create_mcp_server(
            "mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mcp_server = response.parse()
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_create_mcp_server(self, client: Telnyx) -> None:
        with client.ai.missions.mcp_servers.with_streaming_response.create_mcp_server(
            "mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mcp_server = response.parse()
            assert_matches_type(object, mcp_server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_create_mcp_server(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.mcp_servers.with_raw_response.create_mcp_server(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete_mcp_server(self, client: Telnyx) -> None:
        mcp_server = client.ai.missions.mcp_servers.delete_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        )
        assert mcp_server is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete_mcp_server(self, client: Telnyx) -> None:
        response = client.ai.missions.mcp_servers.with_raw_response.delete_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mcp_server = response.parse()
        assert mcp_server is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete_mcp_server(self, client: Telnyx) -> None:
        with client.ai.missions.mcp_servers.with_streaming_response.delete_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mcp_server = response.parse()
            assert mcp_server is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_delete_mcp_server(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.mcp_servers.with_raw_response.delete_mcp_server(
                mcp_server_id="mcp_server_id",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_server_id` but received ''"):
            client.ai.missions.mcp_servers.with_raw_response.delete_mcp_server(
                mcp_server_id="",
                mission_id="mission_id",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_mcp_server(self, client: Telnyx) -> None:
        mcp_server = client.ai.missions.mcp_servers.get_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        )
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_mcp_server(self, client: Telnyx) -> None:
        response = client.ai.missions.mcp_servers.with_raw_response.get_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mcp_server = response.parse()
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_mcp_server(self, client: Telnyx) -> None:
        with client.ai.missions.mcp_servers.with_streaming_response.get_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mcp_server = response.parse()
            assert_matches_type(object, mcp_server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_get_mcp_server(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.mcp_servers.with_raw_response.get_mcp_server(
                mcp_server_id="mcp_server_id",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_server_id` but received ''"):
            client.ai.missions.mcp_servers.with_raw_response.get_mcp_server(
                mcp_server_id="",
                mission_id="mission_id",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_list_mcp_servers(self, client: Telnyx) -> None:
        mcp_server = client.ai.missions.mcp_servers.list_mcp_servers(
            "mission_id",
        )
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_list_mcp_servers(self, client: Telnyx) -> None:
        response = client.ai.missions.mcp_servers.with_raw_response.list_mcp_servers(
            "mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mcp_server = response.parse()
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_list_mcp_servers(self, client: Telnyx) -> None:
        with client.ai.missions.mcp_servers.with_streaming_response.list_mcp_servers(
            "mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mcp_server = response.parse()
            assert_matches_type(object, mcp_server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_list_mcp_servers(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.mcp_servers.with_raw_response.list_mcp_servers(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_update_mcp_server(self, client: Telnyx) -> None:
        mcp_server = client.ai.missions.mcp_servers.update_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        )
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_update_mcp_server(self, client: Telnyx) -> None:
        response = client.ai.missions.mcp_servers.with_raw_response.update_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mcp_server = response.parse()
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_update_mcp_server(self, client: Telnyx) -> None:
        with client.ai.missions.mcp_servers.with_streaming_response.update_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mcp_server = response.parse()
            assert_matches_type(object, mcp_server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_update_mcp_server(self, client: Telnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            client.ai.missions.mcp_servers.with_raw_response.update_mcp_server(
                mcp_server_id="mcp_server_id",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_server_id` but received ''"):
            client.ai.missions.mcp_servers.with_raw_response.update_mcp_server(
                mcp_server_id="",
                mission_id="mission_id",
            )


class TestAsyncMcpServers:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_create_mcp_server(self, async_client: AsyncTelnyx) -> None:
        mcp_server = await async_client.ai.missions.mcp_servers.create_mcp_server(
            "mission_id",
        )
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_create_mcp_server(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.mcp_servers.with_raw_response.create_mcp_server(
            "mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mcp_server = await response.parse()
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_create_mcp_server(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.mcp_servers.with_streaming_response.create_mcp_server(
            "mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mcp_server = await response.parse()
            assert_matches_type(object, mcp_server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_create_mcp_server(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.mcp_servers.with_raw_response.create_mcp_server(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete_mcp_server(self, async_client: AsyncTelnyx) -> None:
        mcp_server = await async_client.ai.missions.mcp_servers.delete_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        )
        assert mcp_server is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete_mcp_server(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.mcp_servers.with_raw_response.delete_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mcp_server = await response.parse()
        assert mcp_server is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete_mcp_server(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.mcp_servers.with_streaming_response.delete_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mcp_server = await response.parse()
            assert mcp_server is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_delete_mcp_server(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.mcp_servers.with_raw_response.delete_mcp_server(
                mcp_server_id="mcp_server_id",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_server_id` but received ''"):
            await async_client.ai.missions.mcp_servers.with_raw_response.delete_mcp_server(
                mcp_server_id="",
                mission_id="mission_id",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_mcp_server(self, async_client: AsyncTelnyx) -> None:
        mcp_server = await async_client.ai.missions.mcp_servers.get_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        )
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_mcp_server(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.mcp_servers.with_raw_response.get_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mcp_server = await response.parse()
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_mcp_server(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.mcp_servers.with_streaming_response.get_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mcp_server = await response.parse()
            assert_matches_type(object, mcp_server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_get_mcp_server(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.mcp_servers.with_raw_response.get_mcp_server(
                mcp_server_id="mcp_server_id",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_server_id` but received ''"):
            await async_client.ai.missions.mcp_servers.with_raw_response.get_mcp_server(
                mcp_server_id="",
                mission_id="mission_id",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_list_mcp_servers(self, async_client: AsyncTelnyx) -> None:
        mcp_server = await async_client.ai.missions.mcp_servers.list_mcp_servers(
            "mission_id",
        )
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_list_mcp_servers(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.mcp_servers.with_raw_response.list_mcp_servers(
            "mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mcp_server = await response.parse()
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_list_mcp_servers(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.mcp_servers.with_streaming_response.list_mcp_servers(
            "mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mcp_server = await response.parse()
            assert_matches_type(object, mcp_server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_list_mcp_servers(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.mcp_servers.with_raw_response.list_mcp_servers(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_update_mcp_server(self, async_client: AsyncTelnyx) -> None:
        mcp_server = await async_client.ai.missions.mcp_servers.update_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        )
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_update_mcp_server(self, async_client: AsyncTelnyx) -> None:
        response = await async_client.ai.missions.mcp_servers.with_raw_response.update_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        mcp_server = await response.parse()
        assert_matches_type(object, mcp_server, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_update_mcp_server(self, async_client: AsyncTelnyx) -> None:
        async with async_client.ai.missions.mcp_servers.with_streaming_response.update_mcp_server(
            mcp_server_id="mcp_server_id",
            mission_id="mission_id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            mcp_server = await response.parse()
            assert_matches_type(object, mcp_server, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_update_mcp_server(self, async_client: AsyncTelnyx) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mission_id` but received ''"):
            await async_client.ai.missions.mcp_servers.with_raw_response.update_mcp_server(
                mcp_server_id="mcp_server_id",
                mission_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `mcp_server_id` but received ''"):
            await async_client.ai.missions.mcp_servers.with_raw_response.update_mcp_server(
                mcp_server_id="",
                mission_id="mission_id",
            )
